==> haskell-hw-prim-0.6.3.2-202-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-prim.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-prim
version:              0.6.3.2
visibility:           public
id:                   hw-prim-0.6.3.2-7OvKkFKxQiffZrRyk1khq
key:                  hw-prim-0.6.3.2-7OvKkFKxQiffZrRyk1khq
license:              BSD-3-Clause
copyright:            2016-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
stability:            Experimental
homepage:             http://github.com/haskell-works/hw-prim#readme
synopsis:             Primitive functions and data types
description:          Primitive functions and data types.
category:             Data
abi:                  11e25e4d6ec94ca4fbae88c43e8f8464
exposed:              True
exposed-modules:
    HaskellWorks.Control.Monad.Lazy HaskellWorks.Data.AtIndex
    HaskellWorks.Data.Branchless HaskellWorks.Data.ByteString
    HaskellWorks.Data.ByteString.Builder
    HaskellWorks.Data.ByteString.Lazy HaskellWorks.Data.Char
    HaskellWorks.Data.Char.IsChar HaskellWorks.Data.Concat
    HaskellWorks.Data.Cons HaskellWorks.Data.Container
    HaskellWorks.Data.Decode HaskellWorks.Data.Drop
    HaskellWorks.Data.Empty HaskellWorks.Data.Filter
    HaskellWorks.Data.Foldable HaskellWorks.Data.FromByteString
    HaskellWorks.Data.FromForeignRegion HaskellWorks.Data.FromString
    HaskellWorks.Data.Generate HaskellWorks.Data.Head
    HaskellWorks.Data.Length HaskellWorks.Data.Naive
    HaskellWorks.Data.Null HaskellWorks.Data.Ops
    HaskellWorks.Data.Positioning HaskellWorks.Data.Product
    HaskellWorks.Data.Search HaskellWorks.Data.Sign
    HaskellWorks.Data.Snoc HaskellWorks.Data.Take
    HaskellWorks.Data.TreeCursor HaskellWorks.Data.Uncons
    HaskellWorks.Data.Unsign HaskellWorks.Data.Unsnoc
    HaskellWorks.Data.Vector.AsVector64
    HaskellWorks.Data.Vector.AsVector64ns
    HaskellWorks.Data.Vector.AsVector64s
    HaskellWorks.Data.Vector.AsVector8
    HaskellWorks.Data.Vector.AsVector8ns
    HaskellWorks.Data.Vector.AsVector8s
    HaskellWorks.Data.Vector.BoxedVectorLike
    HaskellWorks.Data.Vector.Storable
    HaskellWorks.Data.Vector.StorableVectorLike HaskellWorks.Data.Word
    HaskellWorks.Foreign

hidden-modules:       Paths_hw_prim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-prim-0.6.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-prim-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-prim-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-prim
hs-libraries:         HShw-prim-0.6.3.2-7OvKkFKxQiffZrRyk1khq
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1
    mmap-0.5.9-Elwtwd4pUdW5gAqAC4PwUa transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-EKABDCAVgb42yYEtp4rYAX

haddock-interfaces:   /usr/share/doc/haskell-hw-prim/html/hw-prim.haddock
haddock-html:         /usr/share/doc/haskell-hw-prim/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-prim-0.6.3.2-203-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-prim.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-prim
version:              0.6.3.2
visibility:           public
id:                   hw-prim-0.6.3.2-AChvOmvJnXSH4QuokdbOx2
key:                  hw-prim-0.6.3.2-AChvOmvJnXSH4QuokdbOx2
license:              BSD-3-Clause
copyright:            2016-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
stability:            Experimental
homepage:             http://github.com/haskell-works/hw-prim#readme
synopsis:             Primitive functions and data types
description:          Primitive functions and data types.
category:             Data
abi:                  130b485e5618fede1f6bb3517973860b
exposed:              True
exposed-modules:
    HaskellWorks.Control.Monad.Lazy HaskellWorks.Data.AtIndex
    HaskellWorks.Data.Branchless HaskellWorks.Data.ByteString
    HaskellWorks.Data.ByteString.Builder
    HaskellWorks.Data.ByteString.Lazy HaskellWorks.Data.Char
    HaskellWorks.Data.Char.IsChar HaskellWorks.Data.Concat
    HaskellWorks.Data.Cons HaskellWorks.Data.Container
    HaskellWorks.Data.Decode HaskellWorks.Data.Drop
    HaskellWorks.Data.Empty HaskellWorks.Data.Filter
    HaskellWorks.Data.Foldable HaskellWorks.Data.FromByteString
    HaskellWorks.Data.FromForeignRegion HaskellWorks.Data.FromString
    HaskellWorks.Data.Generate HaskellWorks.Data.Head
    HaskellWorks.Data.Length HaskellWorks.Data.Naive
    HaskellWorks.Data.Null HaskellWorks.Data.Ops
    HaskellWorks.Data.Positioning HaskellWorks.Data.Product
    HaskellWorks.Data.Search HaskellWorks.Data.Sign
    HaskellWorks.Data.Snoc HaskellWorks.Data.Take
    HaskellWorks.Data.TreeCursor HaskellWorks.Data.Uncons
    HaskellWorks.Data.Unsign HaskellWorks.Data.Unsnoc
    HaskellWorks.Data.Vector.AsVector64
    HaskellWorks.Data.Vector.AsVector64ns
    HaskellWorks.Data.Vector.AsVector64s
    HaskellWorks.Data.Vector.AsVector8
    HaskellWorks.Data.Vector.AsVector8ns
    HaskellWorks.Data.Vector.AsVector8s
    HaskellWorks.Data.Vector.BoxedVectorLike
    HaskellWorks.Data.Vector.Storable
    HaskellWorks.Data.Vector.StorableVectorLike HaskellWorks.Data.Word
    HaskellWorks.Foreign

hidden-modules:       Paths_hw_prim
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hw-prim-0.6.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-prim
hs-libraries:         HShw-prim-0.6.3.2-AChvOmvJnXSH4QuokdbOx2
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 ghc-prim-0.10.0
    mmap-0.5.9-AiaaDT3AznV3aaEfoYTVVt transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    vector-0.13.2.0-6vtrErFI1tV1Z02auPMCSS

haddock-interfaces:   /usr/share/doc/haskell-hw-prim/html/hw-prim.haddock
haddock-html:         /usr/share/doc/haskell-hw-prim/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
